@@ -1,11 +1,12 @@
 // Take a look at the license at the top of the repository in the LICENSE file.
 
-use crate::ShortcutTrigger;
-use gdk::keys::Key;
-use glib::object::Cast;
-use glib::translate::*;
 use std::fmt;
 
+use gdk::Key;
+use glib::translate::*;
+
+use crate::{ffi, prelude::*, ShortcutTrigger};
+
 glib::wrapper! {
     pub struct KeyvalTrigger(Object<ffi::GtkKeyvalTrigger, ffi::GtkKeyvalTriggerClass>) @extends ShortcutTrigger;
 
@@ -30,7 +31,7 @@ impl KeyvalTrigger {
     #[doc(alias = "gtk_keyval_trigger_get_keyval")]
     #[doc(alias = "get_keyval")]
     pub fn keyval(&self) -> Key {
-        unsafe { ffi::gtk_keyval_trigger_get_keyval(self.to_glib_none().0).into() }
+        unsafe { from_glib(ffi::gtk_keyval_trigger_get_keyval(self.to_glib_none().0)) }
     }
 
     #[doc(alias = "gtk_keyval_trigger_get_modifiers")]
